Function simple_blit::blit_with

source ·
pub fn blit_with<T, U>(
    dest: &mut (impl BufferMut<T> + ?Sized),
    dest_pos: (i32, i32),
    src: &(impl Buffer<U> + ?Sized),
    src_pos: (i32, i32),
    size: (u32, u32),
    opts: BlitOptions,
    f: impl FnMut(&mut T, &U, (u32, u32))
)
Blit one whole buffer to another (generalized function).

Crops the rectangle if it doesn’t fit. f is called for each pair of values, the last argument is their position relative to the (already cropped if necessary) rectangle that is being blitted.